@@ -1,28 +1,24 @@
 require 'test_helper'
 
-class I18nOverrideTest < Test::Unit::TestCase
+class I18nOverrideTest < I18n::TestCase
   module OverrideInverse
-
-    def translate(*args)
-      super(*args).reverse
+    def translate(*args, **options)
+      super(*args, **options).reverse
     end
     alias :t :translate
-
   end
 
   module OverrideSignature
-
     def translate(*args)
       args.first + args[1]
     end
     alias :t :translate
-
   end
 
   def setup
+    super
     @I18n = I18n.dup
     @I18n.backend = I18n::Backend::Simple.new
-    super
   end
 
   test "make sure modules can overwrite I18n methods" do
@@ -30,8 +26,7 @@ class I18nOverrideTest < Test::Unit::TestCase
     @I18n.backend.store_translations('en', :foo => 'bar')
 
     assert_equal 'rab', @I18n.translate(:foo, :locale => 'en')
-    # FIXME: this fails under 1.8.7
-    # assert_equal 'rab', @I18n.t(:foo, :locale => 'en')
+    assert_equal 'rab', @I18n.t(:foo, :locale => 'en')
     assert_equal 'rab', @I18n.translate!(:foo, :locale => 'en')
     assert_equal 'rab', @I18n.t!(:foo, :locale => 'en')
   end
@@ -44,5 +39,4 @@ class I18nOverrideTest < Test::Unit::TestCase
     @I18n.extend OverrideSignature
     assert_equal 'HelloWelcome message on home page', @I18n.translate('Hello', 'Welcome message on home page', :tokenize => true) # tr8n example
   end
-
 end
