@@ -152,6 +152,18 @@ class I18nBackendSimpleTest < I18n::TestCase
     assert_equal false, I18n.backend.initialized?
   end
 
+  test "simple eager_load!: loads the translations" do
+    assert_equal false, I18n.backend.initialized?
+    I18n.backend.eager_load!
+    assert_equal true, I18n.backend.initialized?
+  end
+
+  test "simple reload!: reinitialize the backend if it was previously eager loaded" do
+    I18n.backend.eager_load!
+    I18n.backend.reload!
+    assert_equal true, I18n.backend.initialized?
+  end
+
   test "returns localized string given missing pluralization data" do
     assert_equal 'baz', I18n.t('foo.bar', count: 1)
   end
